@@ -1,8 +1,4 @@
 from .auth import validate_key, get_key
 from .variables import NAME
+from .countries import COUNTRIES
 from .reservation_v2 import ReservationSync
-# import nest_asyncio
-#
-#
-# def setup_nest_asyncio():
-#     nest_asyncio.apply()
