@@ -120,68 +120,11 @@ class Reservation(BaseModel):
 
 
 if __name__ == '__main__':
-    # reservation = Reservation(
-    #     resvId="001",
-    #     agent="ORACLE",
-    #     arrivalDate="2021-01-01",
-    #     departureDate="2021-01-10",
-    #     reservationStatus='NoShow',
-    #     propertyInfo={
-    #         'hotelId': 'SAN01',
-    #         'orgId': 'OHILP',
-    #         'clientId': 'SAN01',
-    #         'agent': 'ORACLE',
-    #         'hotelName': 'OHIP Sandbox 1',
-    #         'numberOfRooms': 1,
-    #         'roomId': '001',
-    #         'roomName': '001',
-    #         'roomType': 'DBL',
-    #         'roomClass': 'STD',
-    #         'roomTypeCharged': 'DBL',
-    #         'roomNumberLocked': False,
-    #         'pseudoRoom':  False
-    #     },
-    #     travel_type=[
-    #         {
-    #             'id': 1,
-    #             'name': 'Business',
-    #             'score': 1,
-    #             'addedBy': 'ALVIE'
-    #         }
-    #     ],
-    #     originalTimeStamp={
-    #         'startDate': '2021-01-21',
-    #         'endDate': '2021-01-31'
-    #     },
-    #     channelInfo={
-    #         'bookingSourceType': '',
-    #         'bookingSourceCode': '',
-    #         'bookingChannelCode': ''
-    #     },
-    #     financialInfo={
-    #         'currencyCode': 'USD',
-    #         'rateAmount': 200,
-    #         'paymentMethod': 'CA',
-    #         'fixedRate': True,
-    #         'rateSuppressed': False,
-    #         'ratePlanCode': 'SDF'
-    #     },
-    #     guestInfo={
-    #         'adultCount': 1,
-    #         'childrenCount': 1,
-    #         'infantCount': 1,
-    #         'guest_list': [
-    #             {
-    #                 'guestId': '0002123',
-    #                 'firstName': 'Harsh',
-    #                 'lastName': 'Mathur',
-    #                 'language': 'E',
-    #             }
-    #         ]
-    #     }
-    # )
-    g = GuestProfile(
-        guestId=123,
-        firstName=None
+    reservation = Reservation(
+
     )
-    print(g.json())
+    # g = GuestProfile(
+    #     guestId=123,
+    #     firstName=None
+    # )
+    # print(g.json())
